"""
This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.
"""

from typing import Any

from sleet.base import BaseAPI


class Diablo3API(BaseAPI):

    def __init__(self, *, api_region: str, api_id: str, api_secret: str):
        super().__init__(api_region=api_region, api_id=api_id, api_secret=api_secret)

    # Diablo3 APIs
    def season_index(self) -> dict[str, Any]:
        """
        Returns an index of available seasons.
        """
        resource = "/data/d3/season/"

        return self._request(resource, None, None)

    def season(self, season_id: int) -> dict[str, Any]:
        """
        Returns a leaderboard list for the specified season.

        :param season_id: The season for the leaderboard list
        """
        resource = f"/data/d3/season/{season_id}"

        return self._request(resource, None, None)

    def season_leaderboard(self, season_id: int, leaderboard: str) -> dict[str, Any]:
        """
        Returns the specified leaderboard for the specified season.

        :param season_id: The season for the leaderboard.
        :param leaderboard: The leaderboard to retrieve (eg. achievement-points)
        """
        resource = f"/data/d3/season/{season_id}/leaderboard/{leaderboard}"

        return self._request(resource, None, None)

    def era_index(self) -> dict[str, Any]:
        """
        Returns an index of available eras.
        """
        resource = "/data/d3/era/"

        return self._request(resource, None, None)

    def era(self, era_id: int) -> dict[str, Any]:
        """
        Returns a leaderboard list for the specified era.

        :param era_id: The era for the leaderboard list
        """
        resource = f"/data/d3/era/{era_id}"

        return self._request(resource, None, None)

    def era_leaderboard(self, era_id: int, leaderboard: str) -> dict[str, Any]:
        """
        Returns the specified leaderboard for the specified era.

        :param era_id: The era for the leaderboard.
        :param leaderboard: The leaderboard to retrieve (eg. rift-barbarian)
        """
        resource = f"/data/d3/era/{era_id}/leaderboard/{leaderboard}"

        return self._request(resource, None, None)
